R

Type Alias R 

pub type R = R<SRCOD_SPEC>;
Register SRCOD reader

Aliased Type

pub struct R { /* private fields */ }

Implementations

Source

impl R

pub fn srcod(&self) -> SRCOD_R

Bits 0:31 - SRCOD is a 32-bit read-only register used to output the data after sampling rate conversion. The data in the 16-stage output data FIFO is read through SRCOD. When the number of data in the output data FIFO is zero after the start of conversion, the value previously read is read again.