pub enum OINT_A {
_0 = 0,
_1 = 1,
}Expand description
Output Data FIFO Full Interrupt Request Flag
Value on reset: 0
Variants
_0 = 0
0: Number of data units in the output FIFO has not become equal to or greater than the specified triggering number.
_1 = 1
1: Number of data units in the output FIFO has become equal to or greater than the specified triggering number.